/**
 * Licensed to the Austrian Association for Software Tool Integration (AASTI)
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. The AASTI licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openengsb.openengsbplugin;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.util.Arrays;

import org.apache.commons.io.FileUtils;
import org.junit.Before;
import org.junit.Test;
import org.openengsb.openengsbplugin.tools.Tools;

public class LicenseFormatTest extends MojoPreparation {

    @Before
    public void buildInvocationCommand() throws Exception {
        prepareGoal("licenseFormat");
    }

    @Test
    public void licenseFormat_writeHeader() throws Exception {
        File projectFile = null;
        try {
            File backupWithoutHeader = new File("src/test/resources/licenseFormat/backup/Without_Header.java");
            File sampleProjSrc = new File("src/test/resources/licenseFormat/sampleproject/src");
            FileUtils.copyFileToDirectory(backupWithoutHeader, sampleProjSrc);

            projectFile = new File(sampleProjSrc, "Without_Header.java");

            int result = Tools.executeProcess(Arrays.asList(new String[] { mvnCommand, "-e", invocation }), new File(
                    "src/test/resources/licenseFormat/sampleproject"));
            assertEquals(0, result);

            File backupWithHeader = new File("src/test/resources/licenseFormat/backup/With_Header.java");
            assertTrue(FileUtils.readFileToString(backupWithHeader).equals(FileUtils.readFileToString(projectFile)));
        } finally {
            FileUtils.deleteQuietly(projectFile);
        }
    }
}
